@@ -139,7 +139,7 @@ SbVec3f::SbVec3f(const SbPlane & p0, const SbPlane & p1, const SbPlane & p2)
 
   // The equation for a point in a plane can be:
   //
-  //                N(P - P0) = 0    , N is the plane's normal vectors,
+  //                N·(P - P0) = 0    , N is the plane's normal vectors,
   //                                    P is the point and P0 is the "root
   //                                    point" of the plane (i.e. the point
   //                                    in the plane closest to the coordinate
@@ -147,13 +147,13 @@ SbVec3f::SbVec3f(const SbPlane & p0, const SbPlane & p1, const SbPlane & p2)
   //
   // Simplifying and substituting, we get this:
   //
-  //                NP = d           , d is the distance from the origin to
+  //                N·P = d           , d is the distance from the origin to
   //                                    the closest point on the plane
   //
   // Using this for all three given planes:
-  //                N0P = d0
-  //                N1P = d1
-  //                N2P = d2
+  //                N0·P = d0
+  //                N1·P = d1
+  //                N2·P = d2
   //
   // Taking the dot products we get a set of linear equations:
   //
@@ -186,7 +186,7 @@ SbVec3f::SbVec3f(const SbPlane & p0, const SbPlane & p1, const SbPlane & p2)
 
 
   int i, j;
-  const int n = 3; // Input matrix dimensions are n  (n+1).
+  const int n = 3; // Input matrix dimensions are n × (n+1).
 
   for (int k=0; k < n-1; k++) {
     j=k;
