@@ -274,7 +274,7 @@ SoCenterballDragger::SoCenterballDragger(void)
                                        static_cast<int>(strlen(CENTERBALLDRAGGER_draggergeometry)));
   }
 
-  SO_KIT_ADD_FIELD(rotation, (SbRotation(SbVec3f(0.0f, 0.0f, 1.0f), 0.0f)));
+  SO_KIT_ADD_FIELD(rotation, (SbRotation::identity()));
   SO_KIT_ADD_FIELD(center, (0.0f, 0.0f, 0.0f));
 
   SO_KIT_INIT_INSTANCE();
