@@ -226,7 +226,7 @@ SoSpotLightDragger::SoSpotLightDragger(void)
                                        static_cast<int>(strlen(SPOTLIGHTDRAGGER_draggergeometry)));
   }
 
-  SO_KIT_ADD_FIELD(rotation, (SbRotation(SbVec3f(0.0f, 0.0f, 1.0f), 0.0f)));
+  SO_KIT_ADD_FIELD(rotation, (SbRotation::identity()));
   SO_KIT_ADD_FIELD(translation, (0.0f, 0.0f, 0.0f));
   SO_KIT_ADD_FIELD(angle, (1.0f));
   SO_KIT_INIT_INSTANCE();
