@@ -724,7 +724,7 @@ SoWWWInlineP::readNamedFile()
   else {
     // Note that we handle this differently than Inventor, which lets
     // the whole import fail.
-    SoReadError::post(&in, "Unable to read subfile: ``%s''",
+    SoReadError::post(&in, "Unable to read subfile: \"%s\"",
                       name.getString());
   }
 
